@@ -86,39 +86,21 @@ impl<'r> JsonCodec for sqlx_core::mysql::MySqlValueRef<'r> {
                 let r: Option<u8> = Decode::<'_, MySql>::decode(self)?;
                 return Ok(new_json_option_into!(r));
             }
-
             "DATE" => {
-                let r: Option<String> = Decode::<'_, MySql>::decode(self)?;
-                if let Some(mut date) = r {
-                    date.check();
-                    return Ok(serde_json::Value::String(date));
-                }
-                return Ok(serde_json::Value::Null);
+                let r: Option<chrono::NaiveDate> = Decode::<'_, MySql>::decode(self)?;
+                return Ok(json!(r));
             }
             "TIME" | "YEAR" => {
-                let r: Option<String> = Decode::<'_, MySql>::decode(self)?;
-                if let Some(mut date) = r {
-                    date.check();
-                    return Ok(serde_json::Value::String(date));
-                }
-                return Ok(serde_json::Value::Null);
+                let r: Option<chrono::NaiveTime> = Decode::<'_, MySql>::decode(self)?;
+                return Ok(json!(r));
             }
             "DATETIME" => {
-                let r: Option<String> = Decode::<'_, MySql>::decode(self)?;
-                if let Some(mut date) = r {
-                    date.check();
-                    println!("{}",date);
-                    return Ok(serde_json::Value::String(date));
-                }
-                return Ok(serde_json::Value::Null);
+                let r: Option<chrono::NaiveDateTime> = Decode::<'_, MySql>::decode(self)?;
+                return Ok(json!(r));
             }
             "TIMESTAMP" => {
-                let r: Option<String> = Decode::<'_, MySql>::decode(self)?;
-                if let Some(mut date) = r {
-                    date.check();
-                    return Ok(serde_json::Value::String(date));
-                }
-                return Ok(serde_json::Value::Null);
+                let r: Option<chrono::NaiveDateTime> = Decode::<'_, MySql>::decode(self)?;
+                return Ok(json!(r));
             }
             "JSON" => {
                 let r: Option<Json<serde_json::Value>> = Decode::<'_, MySql>::decode(self)?;
