@@ -29,17 +29,17 @@ impl<'c> JsonCodec for PgValueRef<'c> {
             }
             "NUMERIC" => {
                 //decimal
-                let r: Option<String> = Decode::<'_, Postgres>::decode(self)?;
+                let r: Option<BigDecimal> = Decode::<'_, Postgres>::decode(self)?;
                 if let Some(date) = r {
-                    return Ok(serde_json::Value::String(date));
+                    return Ok(serde_json::Value::String(date.to_string()));
                 }
                 return Ok(serde_json::Value::Null);
             }
             "NUMERIC[]" => {
                 //decimal
-                let r: Option<Vec<String>> = Decode::<'_, Postgres>::decode(self)?;
+                let r: Option<Vec<BigDecimal>> = Decode::<'_, Postgres>::decode(self)?;
                 if let Some(r) = r {
-                    return Ok(serde_json::Value::from(r));
+                    return Ok(serde_json::json!(r));
                 }
                 return Ok(serde_json::Value::Null);
             }
